==> haskell-status-notifier-item-0.3.1.0-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-CqoYuvxaJEx7Yh8SOE2bxQ
key:                  status-notifier-item-0.3.1.0-CqoYuvxaJEx7Yh8SOE2bxQ
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  30fcbe8c2d63f09bb3822d3c28c7a19f
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-CqoYuvxaJEx7Yh8SOE2bxQ
depends:
    base-4.17.2.1 byte-order-0.1.3.1-Hu8r4g7FHBB9S0OEZOHeWo
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-2sk7Ts2qxQLEJf3Nnzl84h
    containers-0.6.7 dbus-1.3.1-4NTnBCr3mlcIHHY4mrA62g filepath-1.4.2.2
    hslogger-1.3.1.2-9r6004OoCOs6RTVCUN7pE1
    lens-5.2.3-I3BlAHfqsGAEvCz93DUGGV template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    vector-0.13.1.0-DP5vqiFKsIZ25TyoutQAjD

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-status-notifier-item-0.3.1.0-180-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-1q2z9xsj0B4GNmdBwbrmG7
key:                  status-notifier-item-0.3.1.0-1q2z9xsj0B4GNmdBwbrmG7
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  3331d971b95d657f84d39dd24cc43b7e
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-1q2z9xsj0B4GNmdBwbrmG7
depends:
    base-4.17.2.1 byte-order-0.1.3.1-8eLQe37m6mA7wzjUpiKwmT
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-2sk7Ts2qxQLEJf3Nnzl84h
    containers-0.6.7 dbus-1.3.1-38oduk7rSWUB3r1pmNfAv0 filepath-1.4.2.2
    hslogger-1.3.1.2-9r6004OoCOs6RTVCUN7pE1
    lens-5.2.3-JlyZXwZS00NBv5ScwlVipn template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    vector-0.13.1.0-DP5vqiFKsIZ25TyoutQAjD

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
